@@ -301,7 +301,7 @@ KGAPI::Object* Services::CalendarPrivate::JSONToCalendar(const QVariantMap& cale
     object->setLocation(calendar["location"].toString());
     object->setTimezone(calendar["timeZone"].toString());
 
-    if ((calendar["accessRole"].toString() == "writer") || (calendar["acessRole"].toString() == "owner")) {
+    if ((calendar["accessRole"].toString() == "writer") || (calendar["accessRole"].toString() == "owner")) {
         object->setEditable(true);
     } else {
         object->setEditable(false);
@@ -381,7 +381,7 @@ KGAPI::Object* Services::CalendarPrivate::JSONToEvent(const QVariantMap& event)
     }
 
     /* Canceled instance of recurring event. Set ID of the instance to match ID of the event */
-    if (event.contains("recurringEventId") && object->deleted()) {
+    if (event.contains("recurringEventId")) {
         object->setUid(QUrl::fromPercentEncoding(event["recurringEventId"].toByteArray()));
     }
 
